@@ -162,11 +162,17 @@ class pltstyle(styleapplicator):
         update_dicts = self.of(use_main_plot=True, key_filter=key_filter_lambda)
         #This seems to only work for plotly.go objects?
         try:some_figure_obj.update(**update_dicts)
-        except:pass
+        except Exception as e:
+            import os,sys
+            _, _, exc_tb = sys.exc_info();fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(":> Hit an unexpected error |some_figure_obj.update| {0} @ {1}:{2}".format(e, fname, exc_tb.tb_lineno))
 
         #This seems to only work for plotly.express objects?
         try:some_figure_obj.update_layout(**update_dicts)
-        except:pass
+        except Exception as e:
+            import os,sys
+            _, _, exc_tb = sys.exc_info();fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(":> Hit an unexpected error |some_figure_obj.update_layout| {0} @ {1}:{2}".format(e, fname, exc_tb.tb_lineno))
 
         #Changing some per-plot settings since they're traces & annotations
         for key,value in self.subplot_kwargs.items():
@@ -177,12 +183,13 @@ class pltstyle(styleapplicator):
                 settings['color'] = value
             elif key == "subplot.title.font.family":
                 settings['family'] = value
-                
+
                 #Setting all of the titles, they're all annotations?
                 #https://github.com/plotly/plotly.py/issues/985
                 #https://plotly.com/python/reference/layout/yaxis/
                 for i in some_figure_obj['layout']['annotations']:
                     i['font'] = settings
+
         self.clear_screen()
         return some_figure_obj
     def __getitem__(self, key):
